@@ -19,8 +19,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from __future__ import print_function
-
 import os
 
 
@@ -30,11 +28,11 @@ import os
 # that this isn't the 0.15 release version while also allowing us to release
 # an 0.15.1 if need be.  Release versions should use 2-digit version numbers,
 # with 0.16 being the next release version in this example.
-version = "0.26"
+version = "1.0"
 version_info = tuple([int(x) for x in version.split(".")])
 
 
-class UndefType(object):
+class UndefType:
 
     def __repr__(self):
         return "Undef"
