@@ -19,22 +19,20 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from __future__ import print_function
-
 from datetime import datetime, date, time, timedelta
 import json
 
-from distutils.version import LooseVersion
+from packaging.version import parse as parse_version
 
 from storm.databases import dummy
 
 # PostgreSQL support in Storm requires psycopg2 2.3.0 or greater, in order
 # to support the two-phase commit protocol.
-REQUIRED_PSYCOPG2_VERSION = LooseVersion('2.3.0')
+REQUIRED_PSYCOPG2_VERSION = parse_version('2.3.0')
 PSYCOPG2_VERSION = None
 try:
     import psycopg2
-    PSYCOPG2_VERSION = LooseVersion(psycopg2.__version__.split(' ')[0])
+    PSYCOPG2_VERSION = parse_version(psycopg2.__version__.split(' ')[0])
     if PSYCOPG2_VERSION < REQUIRED_PSYCOPG2_VERSION:
         psycopg2 = dummy
     else:
@@ -371,7 +369,7 @@ class Postgres(Database):
     _version = None
 
     def __init__(self, uri):
-        super(Postgres, self).__init__(uri)
+        super().__init__(uri)
         if psycopg2 is dummy:
             raise DatabaseModuleError(
                 "'psycopg2' >= %s not found. Found %s."
@@ -402,15 +400,14 @@ class Postgres(Database):
     _psycopg_error_attributes = tuple(_psycopg_error_attributes)
 
     def _make_combined_exception_type(self, wrapper_type, dbapi_type):
-        combined_type = super(Postgres, self)._make_combined_exception_type(
+        combined_type = super()._make_combined_exception_type(
             wrapper_type, dbapi_type)
         for name in self._psycopg_error_attributes:
             setattr(combined_type, name, lambda err: getattr(err, "_" + name))
         return combined_type
 
     def _wrap_exception(self, wrapper_type, exception):
-        wrapped = super(Postgres, self)._wrap_exception(
-            wrapper_type, exception)
+        wrapped = super()._wrap_exception(wrapper_type, exception)
         for name in self._psycopg_error_attributes:
             setattr(wrapped, "_" + name, getattr(exception, name))
         return wrapped
