@@ -18,8 +18,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-from __future__ import print_function
-
 from bisect import insort_left, bisect_left
 import weakref
 import sys
@@ -41,7 +39,7 @@ __all__ = ["Property", "SimpleProperty",
            "Pickle", "JSON", "List", "PropertyRegistry"]
 
 
-class Property(object):
+class Property:
     """A property representing a database column.
 
     Properties can be set as attributes of classes that have a
@@ -211,8 +209,8 @@ class Decimal(SimpleProperty):
 class Bytes(SimpleProperty):
     """Bytes property.
 
-    This accepts L{bytes}, L{buffer} (Python 2), or L{memoryview} (Python 3)
-    objects, and stores them as byte strings.
+    This accepts L{bytes} or L{memoryview} objects, and stores them as byte
+    strings.
 
     Deprecated aliases: L{Chars}, L{RawStr}.
     """
@@ -228,9 +226,7 @@ RawStr = Bytes
 class Unicode(SimpleProperty):
     """Unicode property.
 
-    This accepts L{unicode} (Python 2) or L{str} (Python 3) objects, and
-    stores them as text strings.  Note that it does not accept L{str}
-    objects on Python 2.
+    This accepts L{str} objects, and stores them as text strings.
     """
     variable_class = UnicodeVariable
 
@@ -367,7 +363,7 @@ class Enum(SimpleProperty):
 
     def __init__(self, name=None, primary=False, **kwargs):
         set_map = dict(kwargs.pop("map"))
-        get_map = dict((value, key) for key, value in set_map.items())
+        get_map = {value: key for key, value in set_map.items()}
         if "set_map" in kwargs:
             set_map = dict(kwargs.pop("set_map"))
 
@@ -376,7 +372,7 @@ class Enum(SimpleProperty):
         SimpleProperty.__init__(self, name, primary, **kwargs)
 
 
-class PropertyRegistry(object):
+class PropertyRegistry:
     """
     An object which remembers the Storm properties specified on
     classes, and is able to translate names to these properties.
