@@ -18,12 +18,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-from __future__ import print_function
-
 import weakref
 
-import six
-
 from storm.exceptions import (
     ClassInfoError, FeatureError, NoStoreError, WrongStoreError)
 from storm.store import Store, get_where_for_args, LostObjectError
@@ -37,7 +33,7 @@ from storm.info import get_cls_info, get_obj_info
 __all__ = ["Reference", "ReferenceSet", "Proxy"]
 
 
-class LazyAttribute(object):
+class LazyAttribute:
     """
     This descriptor will call the named attribute builder to
     initialize the given attribute on first access.  It avoids
@@ -67,7 +63,7 @@ class PendingReferenceValue(LazyValue):
 PendingReferenceValue = PendingReferenceValue()
 
 
-class Reference(object):
+class Reference:
     """Descriptor for one-to-one relationships.
 
     This is typically used when the class that it is being defined on
@@ -216,7 +212,7 @@ class Reference(object):
     __hash__ = object.__hash__
 
 
-class ReferenceSet(object):
+class ReferenceSet:
     """Descriptor for many-to-one and many-to-many reference sets.
 
     This is typically used when another class has a foreign key onto the
@@ -339,7 +335,7 @@ class ReferenceSet(object):
             self._relation2 = None
 
 
-class BoundReferenceSetBase(object):
+class BoundReferenceSetBase:
 
     def find(self, *args, **kwargs):
         store = Store.of(self._local)
@@ -475,7 +471,7 @@ class Proxy(ComparableExpr):
     a native property of C{Foo}.
     """
 
-    class RemoteProp(object):
+    class RemoteProp:
         """
         This descriptor will resolve and set the _remote_prop attribute
         when it's first used. It avoids having a test at every single
@@ -521,7 +517,7 @@ def compile_proxy(compile, proxy, state):
     return compile(proxy._remote_prop, state)
 
 
-class Relation(object):
+class Relation:
 
     def __init__(self, local_key, remote_key, many, on_remote):
         assert type(local_key) is tuple and type(remote_key) is tuple
@@ -967,7 +963,7 @@ class Relation(object):
             return self._r_to_l.setdefault(local_cls, map).get(remote_column)
 
 
-class PropertyResolver(object):
+class PropertyResolver:
     """Transform strings and pure properties (non-columns) into columns."""
 
     def __init__(self, reference, used_cls):
@@ -985,7 +981,7 @@ class PropertyResolver(object):
     def resolve_one(self, property):
         if type(property) is tuple:
             return self.resolve(property)
-        elif isinstance(property, six.string_types):
+        elif isinstance(property, str):
             return self._resolve_string(property)
         elif isinstance(property, SuffixExpr):
             # XXX This covers cases like order_by=Desc("Bar.id"), see #620369.
@@ -1013,14 +1009,14 @@ class PropertyResolver(object):
 
 def _find_descriptor_class(used_cls, descr):
     for cls in used_cls.__mro__:
-        for attr, _descr in six.iteritems(cls.__dict__):
+        for attr, _descr in cls.__dict__.items():
             if _descr is descr:
                 return cls
     raise RuntimeError("Reference used in an unknown class")
 
 def _find_descriptor_obj(used_cls, descr):
     for cls in used_cls.__mro__:
-        for attr, _descr in six.iteritems(cls.__dict__):
+        for attr, _descr in cls.__dict__.items():
             if _descr is descr:
                 return getattr(cls, attr)
     raise RuntimeError("Reference used in an unknown class")
