@@ -37,19 +37,25 @@ from storm.expr import (
 from storm.exceptions import (
     WrongStoreError, NotFlushedError, OrderLoopError, UnorderedError,
     NotOneError, FeatureError, CompileError, LostObjectError, ClassInfoError)
+from storm.properties import PropertyColumn
 from storm import Undef
 from storm.cache import Cache
 from storm.event import EventSystem
 
 
-__all__ = ["Store", "AutoReload", "EmptyResultSet"]
+__all__ = [
+    "AutoReload",
+    "block_access",
+    "EmptyResultSet",
+    "Store",
+    ]
 
 
 PENDING_ADD = 1
 PENDING_REMOVE = 2
 
 
-class Store(object):
+class Store:
     """The Storm Store.
 
     This is the highest-level interface to a database. It manages
@@ -66,21 +72,25 @@ class Store(object):
     def __init__(self, database, cache=None):
         """
         @param database: The L{storm.database.Database} instance to use.
-        @param cache: The cache to use.  Defaults to a L{Cache} storing up to
-            1000 objects at any given time.
+        @param cache: The cache to use.  Defaults to a L{Cache} instance.
         """
+        self._database = database
         self._event = EventSystem(self)
         self._connection = database.connect(self._event)
         self._alive = WeakValueDictionary()
         self._dirty = {}
         self._order = {} # (info, info) = count
         if cache is None:
-            self._cache = Cache(100)
+            self._cache = Cache()
         else:
             self._cache = cache
         self._implicit_flush_block_count = 0
         self._sequence = 0 # Advisory ordering.
 
+    def get_database(self):
+        """Return this Store's Database object."""
+        return self._database
+
     @staticmethod
     def of(obj):
         """Get the Store that the object is associated with.
@@ -96,7 +106,7 @@ class Store(object):
     def execute(self, statement, params=None, noresult=False):
         """Execute a basic query.
 
-        This is just like L{storm.database.Database.execute}, except
+        This is just like L{storm.database.Connection.execute}, except
         that a flush is performed first.
         """
         if self._implicit_flush_block_count == 0:
@@ -107,6 +117,22 @@ class Store(object):
         """Close the connection."""
         self._connection.close()
 
+    def begin(self, xid):
+        """Start a new two-phase transaction.
+
+        @param xid: A L{Xid <storm.xid.Xid>} instance holding identification
+            data for the new transaction.
+        """
+        self._connection.begin(xid)
+
+    def prepare(self):
+        """Prepare a two-phase transaction for the final commit.
+
+        @note: It must be called inside a two-phase transaction started
+            with L{begin}.
+        """
+        self._connection.prepare()
+
     def commit(self):
         """Commit all changes to the database.
 
@@ -163,12 +189,7 @@ class Store(object):
 
         primary_values = tuple(var.get(to_db=True) for var in primary_vars)
         obj_info = self._alive.get((cls_info.cls, primary_values))
-        if obj_info is not None:
-            if obj_info.get("invalidated"):
-                try:
-                    self._validate_alive(obj_info)
-                except LostObjectError:
-                    return None
+        if obj_info is not None and not obj_info.get("invalidated"):
             return self._get_object(obj_info)
 
         where = compare_columns(cls_info.primary_key, primary_vars)
@@ -219,7 +240,7 @@ class Store(object):
         required. An example follows::
 
             join = LeftJoin(Person, Person.id == Company.person_id)
-            print list(store.using(Company, join).find((Company, Person)))
+            print(list(store.using(Company, join).find((Company, Person))))
 
         The previous code snippet will produce an SQL statement
         somewhat similar to this, depending on your backend::
@@ -310,8 +331,8 @@ class Store(object):
                         default_tables=cls_info.table, limit=1)
         result = self._connection.execute(select)
         values = result.get_one()
-        self._set_values(obj_info, cls_info.columns, result, values)
-        obj_info.checkpoint()
+        self._set_values(obj_info, cls_info.columns, result, values,
+                         replace_unknown_lazy=True)
         self._set_clean(obj_info)
 
     def autoreload(self, obj=None):
@@ -454,11 +475,11 @@ class Store(object):
         self._dirty = flushing
 
         predecessors = {}
-        for (before_info, after_info), n in self._order.iteritems():
+        for (before_info, after_info), n in self._order.items():
             if n > 0:
                 before_set = predecessors.get(after_info)
                 if before_set is None:
-                    predecessors[after_info] = set((before_info,))
+                    predecessors[after_info] = {before_info}
                 else:
                     before_set.add(before_info)
 
@@ -530,13 +551,8 @@ class Store(object):
 
             self._enable_change_notification(obj_info)
             self._add_to_alive(obj_info)
-
-            obj_info.checkpoint()
-
         else:
-
             cached_primary_vars = obj_info["primary_vars"]
-            primary_key_idx = cls_info.primary_key_idx
 
             changes = self._get_changes_map(obj_info)
 
@@ -551,9 +567,6 @@ class Store(object):
 
                 self._add_to_alive(obj_info)
 
-
-            obj_info.checkpoint()
-
         self._run_hook(obj_info, "__storm_flushed__")
 
         obj_info.event.emit("flushed")
@@ -567,6 +580,14 @@ class Store(object):
         assert self._implicit_flush_block_count > 0
         self._implicit_flush_block_count -= 1
 
+    def block_access(self):
+        """Block access to the underlying database connection."""
+        self._connection.block_access()
+
+    def unblock_access(self):
+        """Unblock access to the underlying database connection."""
+        self._connection.unblock_access()
+
     def _get_changes_map(self, obj_info, adding=False):
         """Return a {column: variable} dictionary suitable for inserts/updates.
 
@@ -607,7 +628,7 @@ class Store(object):
         """Fill missing values in variables of the given obj_info.
 
         This method will verify which values are unset in obj_info,
-        and set them to AutoReload, or if it's part of the primary
+        and set them to L{AutoReload}, or if it's part of the primary
         key, query the database for the actual values.
 
         @param obj_info: ObjectInfo to have its values filled.
@@ -641,6 +662,8 @@ class Store(object):
                     # must have just been sent to the database, so this
                     # was already set there.
                     variable.set(AutoReload)
+            else:
+                variable.checkpoint()
 
         if missing_columns:
             where = result.get_insert_identity(cls_info.primary_key,
@@ -691,14 +714,14 @@ class Store(object):
             # primary key was extracted from result values.
             obj_info.pop("invalidated", None)
 
-            # We're not sure if the obj is still in memory at this
-            # point.  This will rebuild it if needed.
-            obj = self._get_object(obj_info)
-
             # Take that chance and fill up any undefined variables
             # with fresh data, since we got it anyway.
             self._set_values(obj_info, cls_info.columns, result,
                              values, keep_defined=True)
+
+            # We're not sure if the obj is still in memory at this
+            # point.  This will rebuild it if needed.
+            obj = self._get_object(obj_info)
         else:
             # Nothing found in the cache. Build everything from the ground.
             obj = cls.__new__(cls)
@@ -706,9 +729,8 @@ class Store(object):
             obj_info = get_obj_info(obj)
             obj_info["store"] = self
 
-            self._set_values(obj_info, cls_info.columns, result, values)
-
-            obj_info.checkpoint()
+            self._set_values(obj_info, cls_info.columns, result, values,
+                             replace_unknown_lazy=True)
 
             self._add_to_alive(obj_info)
             self._enable_change_notification(obj_info)
@@ -741,31 +763,35 @@ class Store(object):
             func()
 
     def _set_values(self, obj_info, columns, result, values,
-                    keep_defined=False):
+                    keep_defined=False, replace_unknown_lazy=False):
         if values is None:
             raise LostObjectError("Can't obtain values from the database "
                                   "(object got removed?)")
         obj_info.pop("invalidated", None)
         for column, value in zip(columns, values):
             variable = obj_info.variables[column]
+            lazy_value = variable.get_lazy()
+            is_unknown_lazy = not (lazy_value is None or
+                                   lazy_value is AutoReload)
             if keep_defined:
-                if variable.is_defined():
+                if variable.is_defined() or is_unknown_lazy:
                     continue
-                lazy_value = variable.get_lazy()
-                if not (lazy_value is None or lazy_value is AutoReload):
-                    # This should *never* happen, because whenever we get
-                    # to this point it should be after a flush() which
-                    # updated the database with lazy values and then replaced
-                    # them by AutoReload.  Letting this go through means
-                    # we're blindly discarding an unknown lazy value and
-                    # replacing it by the value from the database.
-                    raise RuntimeError("Unexpected situation. "
-                                       "Please contact the developers.")
+            elif is_unknown_lazy and not replace_unknown_lazy:
+                # This should *never* happen, because whenever we get
+                # to this point it should be after a flush() which
+                # updated the database with lazy values and then replaced
+                # them by AutoReload.  Letting this go through means
+                # we're blindly discarding an unknown lazy value and
+                # replacing it by the value from the database.
+                raise RuntimeError("Unexpected situation. "
+                                   "Please contact the developers.")
             if value is None:
                 variable.set(value, from_db=True)
             else:
                 result.set_variable(variable, value)
 
+            variable.checkpoint()
+
 
     def _is_dirty(self, obj_info):
         return obj_info in self._dirty
@@ -828,7 +854,7 @@ class Store(object):
             del obj_info["primary_vars"]
 
     def _iter_alive(self):
-        return self._alive.values()
+        return list(self._alive.values())
 
     def _enable_change_notification(self, obj_info):
         obj_info.event.emit("start-tracking-changes", self._event)
@@ -864,7 +890,7 @@ class Store(object):
 
         This method is hooked into the obj_info to resolve variables
         set to lazy values when they're accessed.  It will first flush
-        the store, and then set all variables set to AutoReload to
+        the store, and then set all variables set to L{AutoReload} to
         their database values.
         """
         if lazy_value is not AutoReload and not isinstance(lazy_value, Expr):
@@ -886,14 +912,13 @@ class Store(object):
         if autoreload_columns:
             where = compare_columns(obj_info.cls_info.primary_key,
                                     obj_info["primary_vars"])
-            result = self._connection.execute(Select(autoreload_columns, where))
+            result = self._connection.execute(
+                Select(autoreload_columns, where))
             self._set_values(obj_info, autoreload_columns,
                              result, result.get_one())
-            for column in autoreload_columns:
-                obj_info.variables[column].checkpoint()
 
 
-class ResultSet(object):
+class ResultSet:
     """The representation of the results of a query.
 
     Note that having an instance of this class does not indicate that
@@ -903,6 +928,7 @@ class ResultSet(object):
     Generally these should not be constructed directly, but instead
     retrieved from calls to L{Store.find}.
     """
+
     def __init__(self, store, find_spec,
                  where=Undef, tables=Undef, select=Undef):
         self._store = store
@@ -922,13 +948,18 @@ class ResultSet(object):
         """
         result_set = object.__new__(self.__class__)
         result_set.__dict__.update(self.__dict__)
+        if self._select is not Undef:
+            # This expression must be copied because we may have to change it
+            # in-place inside _get_select().
+            result_set._select = copy(self._select)
         return result_set
 
     def config(self, distinct=None, offset=None, limit=None):
         """Configure this result object in-place. All parameters are optional.
 
-        @param distinct: Boolean enabling/disabling usage of the DISTINCT
-            keyword in the query made.
+        @param distinct: If True, enables usage of the DISTINCT keyword in
+            the query. If a tuple or list of columns, inserts a DISTINCT ON
+            (only supported by PostgreSQL).
         @param offset: Offset where results will start to be retrieved
             from the result set.
         @param limit: Limit the number of objects retrieved from the
@@ -973,10 +1004,11 @@ class ResultSet(object):
     def __getitem__(self, index):
         """Get an individual item by offset, or a range of items by slice.
 
-        If a slice is used, a new L{ResultSet} will be return
-        appropriately modified with OFFSET and LIMIT clauses.
+        @return: The matching object or, if a slice is used, a new
+            L{ResultSet} will be returned appropriately modified with
+            C{OFFSET} and C{LIMIT} clauses.
         """
-        if isinstance(index, (int, long)):
+        if isinstance(index, int):
             if index == 0:
                 result_set = self
             else:
@@ -984,7 +1016,7 @@ class ResultSet(object):
                     index += self._offset
                 result_set = self.copy()
                 result_set.config(offset=index, limit=1)
-            obj = result_set.any()
+            obj = result_set._any()
             if obj is None:
                 raise IndexError("Index out of range")
             return obj
@@ -1040,9 +1072,10 @@ class ResultSet(object):
         return result.get_one() is not None
 
     def is_empty(self):
-        """Return true if this L{ResultSet} contains no results."""
+        """Return C{True} if this result set doesn't contain any results."""
         subselect = self._get_select()
         subselect.limit = 1
+        subselect.order_by = Undef
         select = Select(1, tables=Alias(subselect, "_tmp"), limit=1)
         result = self._store._connection.execute(select)
         return (not result.get_one())
@@ -1050,7 +1083,22 @@ class ResultSet(object):
     def any(self):
         """Return a single item from the result set.
 
-        See also one(), first(), and last().
+        @return: An arbitrary object or C{None} if one isn't available.
+        @see: L{one}, L{first}, and L{last}.
+        """
+        select = self._get_select()
+        select.limit = 1
+        select.order_by = Undef
+        result = self._store._connection.execute(select)
+        values = result.get_one()
+        if values:
+            return self._load_objects(result, values)
+        return None
+
+    def _any(self):
+        """Return a single item from the result without changing sort order.
+
+        @return: An arbitrary object or C{None} if one isn't available.
         """
         select = self._get_select()
         select.limit = 1
@@ -1063,20 +1111,21 @@ class ResultSet(object):
     def first(self):
         """Return the first item from an ordered result set.
 
-        Will raise UnorderedError if the result set isn't ordered.
-
-        See also last(), one(), and any().
+        @raises UnorderedError: Raised if the result set isn't ordered.
+        @return: The first object or C{None} if one isn't available.
+        @see: L{last}, L{one}, and L{any}.
         """
         if self._order_by is Undef:
             raise UnorderedError("Can't use first() on unordered result set")
-        return self.any()
+        return self._any()
 
     def last(self):
         """Return the last item from an ordered result set.
 
-        Will raise UnorderedError if the result set isn't ordered.
-
-        See also first(), one(), and any().
+        @raises FeatureError: Raised if the result set has a C{LIMIT} set.
+        @raises UnorderedError: Raised if the result set isn't ordered.
+        @return: The last object or C{None} if one isn't available.
+        @see: L{first}, L{one}, and L{any}.
         """
         if self._order_by is Undef:
             raise UnorderedError("Can't use last() on unordered result set")
@@ -1103,9 +1152,10 @@ class ResultSet(object):
     def one(self):
         """Return one item from a result set containing at most one item.
 
-        Will raise NotOneError if the result set contains more than one item.
-
-        See also first(), one(), and any().
+        @raises NotOneError: Raised if the result set contains more than one
+            item.
+        @return: The object or C{None} if one isn't available.
+        @see: L{first}, L{last}, and L{any}.
         """
         select = self._get_select()
         # limit could be 1 due to slicing, for instance.
@@ -1200,13 +1250,17 @@ class ResultSet(object):
                 alias = Alias(expr, "_expr")
                 columns.append(alias)
                 aggregate = aggregate_func(alias)
-            subquery = replace_columns(self._get_select(), columns)
+            # Ordering probably doesn't matter for any aggregates, and since
+            # replace_columns() blows up on an ordered query, we'll drop it.
+            select = self._get_select()
+            select.order_by = Undef
+            subquery = replace_columns(select, columns)
             select = Select(aggregate, tables=Alias(subquery, "_tmp"))
         result = self._store._connection.execute(select)
         value = result.get_one()[0]
         variable_factory = getattr(column, "variable_factory", None)
         if variable_factory:
-            variable = variable_factory()
+            variable = variable_factory(allow_none=True)
             result.set_variable(variable, value)
             return variable.get()
         return value
@@ -1234,6 +1288,27 @@ class ResultSet(object):
         """Get the sum of all values in an expression."""
         return self._aggregate(Sum, expr, expr)
 
+    def get_select_expr(self, *columns):
+        """Get a L{Select} expression to retrieve only the specified columns.
+
+        @param columns: One or more L{storm.expr.Column} objects whose values
+            will be fetched.
+        @raises FeatureError: Raised if no columns are specified or if this
+            result is a set expression such as a union.
+        @return: A L{Select} expression configured to use the query parameters
+            specified for this result set, and also limited to only retrieving
+            data for the specified columns.
+        """
+        if not columns:
+            raise FeatureError("select() takes at least one column "
+                               "as argument")
+        if self._select is not Undef:
+            raise FeatureError(
+                "Can't generate subselect expression for set expressions")
+        select = self._get_select()
+        select.columns = columns
+        return select
+
     def values(self, *columns):
         """Retrieve only the specified columns.
 
@@ -1241,12 +1316,16 @@ class ResultSet(object):
 
         @param columns: One or more L{storm.expr.Column} objects whose
             values will be fetched.
+        @raises FeatureError: Raised if no columns are specified or if this
+            result is a set expression such as a union.
         @return: An iterator of tuples of the values for each column
             from each matching row in the database.
         """
         if not columns:
             raise FeatureError("values() takes at least one column "
                                "as argument")
+        if self._select is not Undef:
+            raise FeatureError("values() can't be used with set expressions")
         select = self._get_select()
         select.columns = columns
         result = self._store._connection.execute(select)
@@ -1328,7 +1407,7 @@ class ResultSet(object):
                     for column in changes:
                         obj_info.variables[column].set(AutoReload)
         else:
-            changes = changes.items()
+            changes = list(changes.items())
             for obj in cached:
                 for column, value in changes:
                     variables = get_obj_info(obj).variables
@@ -1358,10 +1437,11 @@ class ResultSet(object):
             match = None
         else:
             match = compile_python.get_matcher(self._where)
+
             def get_column(column):
                 return obj_info.variables[column].get()
+
         objects = []
-        cls = self._find_spec.default_cls_info.cls
         for obj_info in self._store._iter_alive():
             try:
                 if (obj_info.cls_info is self._find_spec.default_cls_info and
@@ -1438,7 +1518,7 @@ class ResultSet(object):
         return self._set_expr(Intersect, other, all)
 
 
-class EmptyResultSet(object):
+class EmptyResultSet:
     """An object that looks like a L{ResultSet} but represents no rows.
 
     This is convenient for application developers who want to provide
@@ -1458,20 +1538,20 @@ class EmptyResultSet(object):
     def __init__(self, ordered=False):
         self._order_by = ordered
 
-    def _get_select(self):
-        return Select(SQLRaw("1"), SQLRaw("1 = 2"))
-
     def copy(self):
         result = EmptyResultSet(self._order_by)
         return result
 
     def config(self, distinct=None, offset=None, limit=None):
-        pass
+        return self
 
     def __iter__(self):
         return
         yield None
 
+    def __len__(self):
+        return 0
+
     def __getitem__(self, index):
         return self.copy()
 
@@ -1501,6 +1581,9 @@ class EmptyResultSet(object):
         self._order_by = True
         return self
 
+    def group_by(self, *expr):
+        return self
+
     def remove(self):
         return 0
 
@@ -1519,6 +1602,21 @@ class EmptyResultSet(object):
     def sum(self, column):
         return None
 
+    def get_select_expr(self, *columns):
+        """Get a L{Select} expression to retrieve only the specified columns.
+
+        @param columns: One or more L{storm.expr.Column} objects whose values
+            will be fetched.
+        @raises FeatureError: Raised if no columns are specified.
+        @return: A L{Select} expression configured to use the query parameters
+            specified for this result set.  The result of the select will
+            always be an empty set of rows.
+        """
+        if not columns:
+            raise FeatureError("select() takes at least one column "
+                               "as argument")
+        return Select(columns, False)
+
     def values(self, *columns):
         if not columns:
             raise FeatureError("values() takes at least one column "
@@ -1547,7 +1645,7 @@ class EmptyResultSet(object):
         return self
 
 
-class TableSet(object):
+class TableSet:
     """The representation of a set of tables which can be queried at once.
 
     This will typically be constructed by a call to L{Store.using}.
@@ -1577,7 +1675,7 @@ Store._result_set_factory = ResultSet
 Store._table_set = TableSet
 
 
-class FindSpec(object):
+class FindSpec:
     """The set of tables or expressions in the result of L{Store.find}."""
 
     def __init__(self, cls_spec):
@@ -1617,7 +1715,12 @@ class FindSpec(object):
         return columns, default_tables
 
     def is_compatible(self, find_spec):
-        """Return True if this FindSpec is compatible with a second one."""
+        """Return True if this FindSpec is compatible with a second one.
+
+        Two FindSpecs are considered compatible if either the find specs
+        are identical (i.e. specifies the same classes and columns) or
+        the find spec columns are of the same type.
+        """
         if self.is_tuple != find_spec.is_tuple:
             return False
         if len(self._cls_spec_info) != len(find_spec._cls_spec_info):
@@ -1626,7 +1729,18 @@ class FindSpec(object):
             self._cls_spec_info, find_spec._cls_spec_info):
             if is_expr1 != is_expr2:
                 return False
-            if info1 is not info2:
+            # If both infos are PropertyColumns, check whether they are
+            # of the same type. Ideally we should check that the types as
+            # defined in the database are the same, but checking the
+            # variable class is easier and will work most of the time.
+            if isinstance(info1, PropertyColumn):
+                if not isinstance(info2, PropertyColumn):
+                    return False
+                variable_class1 = info1.variable_factory().__class__
+                variable_class2 = info2.variable_factory().__class__
+                if variable_class1 is not variable_class2:
+                    return False
+            elif info1 is not info2:
                 return False
         return True
 
@@ -1743,3 +1857,21 @@ class AutoReload(LazyValue):
     pass
 
 AutoReload = AutoReload()
+
+
+class block_access:
+    """
+    Context manager blocks database access by one or more L{Store}\\ s in the
+    managed scope.
+    """
+
+    def __init__(self, *args):
+        self.stores = args
+
+    def __enter__(self):
+        for store in self.stores:
+            store.block_access()
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        for store in self.stores:
+            store.unblock_access()
