@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 from fixtures import Fixture
 
 from storm.tracer import BaseStatementTracer, install_tracer, remove_tracer
@@ -18,7 +16,7 @@ class CaptureTracer(BaseStatementTracer, Fixture):
     """
 
     def __init__(self):
-        super(CaptureTracer, self).__init__()
+        super().__init__()
         self.queries = []
 
     def _setUp(self):
