@@ -18,13 +18,9 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-from __future__ import print_function
-
 from weakref import ref
 import gc
 
-import six
-
 from storm.exceptions import ClassInfoError
 from storm.properties import Property
 from storm.variables import Variable
@@ -33,7 +29,7 @@ from storm.info import *
 from storm.tests.helper import TestHelper
 
 
-class Wrapper(object):
+class Wrapper:
 
     def __init__(self, obj):
         self.obj = obj
@@ -46,7 +42,7 @@ class GetTest(TestHelper):
 
     def setUp(self):
         TestHelper.setUp(self)
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             prop1 = Property("column1", primary=True)
         self.Class = Class
@@ -78,7 +74,7 @@ class ClassInfoTest(TestHelper):
 
     def setUp(self):
         TestHelper.setUp(self)
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             prop1 = Property("column1", primary=True)
             prop2 = Property("column2")
@@ -86,7 +82,7 @@ class ClassInfoTest(TestHelper):
         self.cls_info = get_cls_info(Class)
 
     def test_invalid_class(self):
-        class Class(object): pass
+        class Class: pass
         self.assertRaises(ClassInfoError, ClassInfo, Class)
 
     def test_cls(self):
@@ -114,7 +110,7 @@ class ClassInfoTest(TestHelper):
         self.assertEqual(len(self.cls_info.primary_key), 1)
 
     def test_primary_key_composed(self):
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             prop1 = Property("column1", primary=2)
             prop2 = Property("column2", primary=1)
@@ -126,7 +122,7 @@ class ClassInfoTest(TestHelper):
         self.assertEqual(len(cls_info.primary_key), 2)
 
     def test_primary_key_composed_with_attribute(self):
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             __storm_primary__ = "prop2", "prop1"
             # Define primary=True to ensure that the attribute
@@ -141,21 +137,21 @@ class ClassInfoTest(TestHelper):
         self.assertEqual(len(cls_info.primary_key), 2)
 
     def test_primary_key_composed_duplicated(self):
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             prop1 = Property("column1", primary=True)
             prop2 = Property("column2", primary=True)
         self.assertRaises(ClassInfoError, ClassInfo, Class)
 
     def test_primary_key_missing(self):
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             prop1 = Property("column1")
             prop2 = Property("column2")
         self.assertRaises(ClassInfoError, ClassInfo, Class)
 
     def test_primary_key_attribute_missing(self):
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             __storm_primary__ = ()
             prop1 = Property("column1", primary=True)
@@ -163,7 +159,7 @@ class ClassInfoTest(TestHelper):
         self.assertRaises(ClassInfoError, ClassInfo, Class)
 
     def test_primary_key_pos(self):
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             prop1 = Property("column1", primary=2)
             prop2 = Property("column2")
@@ -176,7 +172,7 @@ class ObjectInfoTest(TestHelper):
 
     def setUp(self):
         TestHelper.setUp(self)
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             prop1 = Property("column1", primary=True)
             prop2 = Property("column2")
@@ -218,7 +214,7 @@ class ObjectInfoTest(TestHelper):
         args = []
         def validator(obj, attr, value):
             args.append((obj, attr, value))
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             prop = Property(primary=True,
                             variable_kwargs={"validator": validator})
@@ -526,7 +522,7 @@ class ClassAliasTest(TestHelper):
 
     def setUp(self):
         TestHelper.setUp(self)
-        class Class(object):
+        class Class:
             __storm_table__ = "table"
             prop1 = Property("column1", primary=True)
         self.Class = Class
@@ -572,7 +568,7 @@ class ClassAliasTest(TestHelper):
                 cls = type.__new__(meta_cls, name, bases, dict)
                 cls.__storm_table__ = "HAH! GOTCH YA!"
                 return cls
-        class Class(six.with_metaclass(MetaClass, object)):
+        class Class(metaclass=MetaClass):
             __storm_table__ = "table"
             prop1 = Property("column1", primary=True)
         Alias = ClassAlias(Class, "USE_THIS")
@@ -628,10 +624,10 @@ class TypeCompilerTest(TestHelper):
 
     def test_nested_classes(self):
         """Convoluted case checking that the model is right."""
-        class Class1(object):
+        class Class1:
             __storm_table__ = "class1"
             id = Property(primary=True)
-        class Class2(object):
+        class Class2:
             __storm_table__ = Class1
             id = Property(primary=True)
         statement = compile(Class2)
