@@ -18,15 +18,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-from __future__ import print_function
-
-import six
-from six.moves.urllib.parse import quote
+from urllib.parse import quote
 
 from storm.exceptions import URIError
 
 
-class URI(object):
+class URI:
     """A representation of a Uniform Resource Identifier (URI).
 
     This is intended exclusively for database connection URIs.
@@ -117,7 +114,7 @@ class URI(object):
             append(escape(self.database, "/"))
         if self.options:
             options = ["%s=%s" % (escape(key), escape(value))
-                       for key, value in sorted(six.iteritems(self.options))]
+                       for key, value in sorted(self.options.items())]
             append("?")
             append("&".join(options))
         return "".join(tokens)
