@@ -18,13 +18,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-from __future__ import print_function
-
 from zope.interface import Interface
 from zope.schema import TextLine
 
 
 class IStoreDirective(Interface):
 
-    name = TextLine(title=u"Name", description=u"Store name")
-    uri = TextLine(title=u"URI", description=u"Database URI")
+    name = TextLine(title="Name", description="Store name")
+    uri = TextLine(title="URI", description="Database URI")
