@@ -24,14 +24,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-from __future__ import print_function
-
 import threading
 import weakref
 
 from uuid import uuid4
 
-import six
 from zope.interface import implementer
 
 import transaction
@@ -48,7 +45,7 @@ from storm.xid import Xid
 
 
 @implementer(IZStorm)
-class ZStorm(object):
+class ZStorm:
     """A utility which integrates Storm with Zope.
 
     Typically, applications will register stores using ZCML similar
@@ -211,7 +208,7 @@ class ZStorm(object):
         # it to avoid the problem where a store is deallocated during
         # iteration causing RuntimeError: dictionary changed size
         # during iteration.
-        for store, name in list(six.iteritems(self._name_index)):
+        for store, name in list(self._name_index.items()):
             yield name, store
 
     def get_name(self, store):
@@ -258,7 +255,7 @@ def register_store_with_transaction(store, zstorm_ref):
 
 
 @implementer(IDataManager)
-class StoreDataManager(object):
+class StoreDataManager:
     """An L{IDataManager} implementation for C{ZStorm}."""
 
     def __init__(self, store, zstorm):
